Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2894)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/dom_distiller/ReaderModeManagerDelegate.java

Issue 2098683002: Refactor OverlayPanel height calculations (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix tests Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/dom_distiller/ReaderModeManagerDelegate.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/dom_distiller/ReaderModeManagerDelegate.java b/chrome/android/java/src/org/chromium/chrome/browser/dom_distiller/ReaderModeManagerDelegate.java
index 56513ef256d96cf2c18d02a973e4515e3df1a1f5..78869c37c7a25c087d9fa7af2b6edfc83e005ee8 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/dom_distiller/ReaderModeManagerDelegate.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/dom_distiller/ReaderModeManagerDelegate.java
@@ -65,7 +65,7 @@ public interface ReaderModeManagerDelegate {
void recordTimeSpentInReader(long timeInMs);
/**
* Notification that the size of the view has changed.
*/
- void onSizeChanged();
+ void onLayoutChanged();
}

Powered by Google App Engine
@@ -65,7 +65,7 @@ public interface ReaderModeManagerDelegate {
void recordTimeSpentInReader(long timeInMs);
/**
- * Notification that the size of the view has changed.
+ * Notification that the layout has changed.
*/
This is Rietveld 408576698